the Akaike information criterion value when a single model is passed to the function; otherwise, a data.frame with the Akaike information criterion values and the number of parameters is returned.
Arguments
object
an object of the class bellreg.
...
further arguments passed to or from other methods.
k
numeric, the penalty per parameter to be used; the default k = 2 is the classical AIC.